summaryrefslogtreecommitdiff
path: root/xmake/modules/package/tools/xmake.lua
diff options
context:
space:
mode:
Diffstat (limited to 'xmake/modules/package/tools/xmake.lua')
-rw-r--r--xmake/modules/package/tools/xmake.lua8
1 files changed, 4 insertions, 4 deletions
diff --git a/xmake/modules/package/tools/xmake.lua b/xmake/modules/package/tools/xmake.lua
index 379a46d19..27c0bd872 100644
--- a/xmake/modules/package/tools/xmake.lua
+++ b/xmake/modules/package/tools/xmake.lua
@@ -77,10 +77,10 @@ function _get_configs_for_windows(package, configs, opt)
table.insert(configs, "--" .. name .. "=" .. tostring(value))
end
end
- -- pass vs_runtime from package configs
- local vs_runtime = package:config("vs_runtime")
- if vs_runtime then
- table.insert(configs, "--vs_runtime=" .. vs_runtime)
+ -- pass runtimes from package configs
+ local runtimes = package:config("runtimes")
+ if runtimes then
+ table.insert(configs, "--runtimes=" .. runtimes)
end
_get_configs_for_qt(package, configs, opt)
_get_configs_for_vcpkg(package, configs, opt)